'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var accounting = _interopDefault(require('accounting'));
var dateFns = require('date-fns');
var dateFnsTz = require('date-fns-tz');

function _defineProperties(target, props) {
  for (var i = 0; i < props.length; i++) {
    var descriptor = props[i];
    descriptor.enumerable = descriptor.enumerable || false;
    descriptor.configurable = true;
    if ("value" in descriptor) descriptor.writable = true;
    Object.defineProperty(target, descriptor.key, descriptor);
  }
}

function _createClass(Constructor, protoProps, staticProps) {
  if (protoProps) _defineProperties(Constructor.prototype, protoProps);
  if (staticProps) _defineProperties(Constructor, staticProps);
  return Constructor;
}

function _extends() {
  _extends = Object.assign || function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };

  return _extends.apply(this, arguments);
}

function getCurrencies() {
  return [{
    id: 'AED',
    name: 'UAE Dirham',
    fractionSize: 2,
    symbol: {
      grapheme: '.د.إ',
      template: '1 $',
      rtl: true
    },
    uniqSymbol: null
  }, {
    id: 'AFN',
    name: 'Afghani',
    fractionSize: 2,
    symbol: {
      grapheme: '؋',
      template: '1 $',
      rtl: true
    },
    uniqSymbol: {
      grapheme: '؋',
      template: '1 $',
      rtl: true
    }
  }, {
    id: 'ALL',
    name: 'Lek',
    fractionSize: 2,
    symbol: {
      grapheme: 'L',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: 'Lek',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'AMD',
    name: 'Armenian Dram',
    fractionSize: 2,
    symbol: {
      grapheme: 'դր.',
      template: '1 $',
      rtl: false
    },
    uniqSymbol: {
      grapheme: 'դր.',
      template: '1 $',
      rtl: false
    }
  }, {
    id: 'ANG',
    name: 'Netherlands Antillean Guilder',
    fractionSize: 2,
    symbol: {
      grapheme: 'ƒ',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: 'NAƒ',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'AOA',
    name: 'Kwanza',
    fractionSize: 2,
    symbol: null,
    uniqSymbol: null
  }, {
    id: 'ARS',
    name: 'Argentine Peso',
    fractionSize: 2,
    symbol: {
      grapheme: '$',
      template: '$1',
      rtl: false
    },
    uniqSymbol: null
  }, {
    id: 'AUD',
    name: 'Australian Dollar',
    fractionSize: 2,
    symbol: {
      grapheme: '$',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: 'A$',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'AWG',
    name: 'Aruban Florin',
    fractionSize: 2,
    symbol: {
      grapheme: 'ƒ',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: 'Afl',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'AZN',
    name: 'Azerbaijanian Manat',
    fractionSize: 2,
    symbol: {
      grapheme: '₼',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: '₼',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'BAM',
    name: 'Convertible Mark',
    fractionSize: 2,
    symbol: {
      grapheme: 'KM',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: 'KM',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'BBD',
    name: 'Barbados Dollar',
    fractionSize: 2,
    symbol: {
      grapheme: '$',
      template: '$1',
      rtl: false
    },
    uniqSymbol: null
  }, {
    id: 'BDT',
    name: 'Taka',
    fractionSize: 2,
    symbol: null,
    uniqSymbol: null
  }, {
    id: 'BGN',
    name: 'Bulgarian Lev',
    fractionSize: 2,
    symbol: {
      grapheme: 'лв',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: 'лв',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'BHD',
    name: 'Bahraini Dinar',
    fractionSize: 3,
    symbol: {
      grapheme: '.د.ب',
      template: '1 $',
      rtl: true
    },
    uniqSymbol: {
      grapheme: '.د.ب',
      template: '1 $',
      rtl: true
    }
  }, {
    id: 'BIF',
    name: 'Burundi Franc',
    fractionSize: 0,
    symbol: null,
    uniqSymbol: null
  }, {
    id: 'BMD',
    name: 'Bermudian Dollar',
    fractionSize: 2,
    symbol: {
      grapheme: '$',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: 'BD$',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'BND',
    name: 'Brunei Dollar',
    fractionSize: 2,
    symbol: {
      grapheme: '$',
      template: '$1',
      rtl: false
    },
    uniqSymbol: null
  }, {
    id: 'BOB',
    name: 'Boliviano',
    fractionSize: 2,
    symbol: {
      grapheme: 'Bs.',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: 'Bs.',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'BOV',
    name: 'Mvdol',
    fractionSize: 2,
    symbol: null,
    uniqSymbol: null
  }, {
    id: 'BRL',
    name: 'Brazilian Real',
    fractionSize: 2,
    symbol: {
      grapheme: 'R$',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: 'R$',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'BSD',
    name: 'Bahamian Dollar',
    fractionSize: 2,
    symbol: {
      grapheme: '$',
      template: '$1',
      rtl: false
    },
    uniqSymbol: null
  }, {
    id: 'BTN',
    name: 'Ngultrum',
    fractionSize: 2,
    symbol: null,
    uniqSymbol: null
  }, {
    id: 'BWP',
    name: 'Pula',
    fractionSize: 2,
    symbol: {
      grapheme: 'P',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: 'P',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'BYN',
    name: 'Belarussian Ruble',
    fractionSize: 2,
    symbol: {
      grapheme: 'p.',
      template: '1 $',
      rtl: false
    },
    uniqSymbol: {
      grapheme: 'р.',
      template: '1 $',
      rtl: false
    }
  }, {
    id: 'BYR',
    name: 'Belarussian Ruble',
    fractionSize: 0,
    symbol: {
      grapheme: 'p.',
      template: '1 $',
      rtl: false
    },
    uniqSymbol: {
      grapheme: 'р.',
      template: '1 $',
      rtl: false
    }
  }, {
    id: 'BZD',
    name: 'Belize Dollar',
    fractionSize: 2,
    symbol: {
      grapheme: 'BZ$',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: 'BZ$',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'CAD',
    name: 'Canadian Dollar',
    fractionSize: 2,
    symbol: {
      grapheme: '$',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: 'CA$',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'CDF',
    name: 'Congolese Franc',
    fractionSize: 2,
    symbol: null,
    uniqSymbol: null
  }, {
    id: 'CHE',
    name: 'WIR Euro',
    fractionSize: 2,
    symbol: null,
    uniqSymbol: null
  }, {
    id: 'CHF',
    name: 'Swiss Franc',
    fractionSize: 2,
    symbol: null,
    uniqSymbol: null
  }, {
    id: 'CHW',
    name: 'WIR Franc',
    fractionSize: 2,
    symbol: null,
    uniqSymbol: null
  }, {
    id: 'CLF',
    name: 'Unidad de Fomento',
    fractionSize: 4,
    symbol: null,
    uniqSymbol: null
  }, {
    id: 'CLP',
    name: 'Chilean Peso',
    fractionSize: 0,
    symbol: {
      grapheme: '$',
      template: '$1',
      rtl: false
    },
    uniqSymbol: null
  }, {
    id: 'CNY',
    name: 'Yuan Renminbi',
    fractionSize: 2,
    symbol: {
      grapheme: '元',
      template: '1 $',
      rtl: false
    },
    uniqSymbol: {
      grapheme: '元',
      template: '1 $',
      rtl: false
    }
  }, {
    id: 'COP',
    name: 'Colombian Peso',
    fractionSize: 0,
    symbol: {
      grapheme: '$',
      template: '$1',
      rtl: false
    },
    uniqSymbol: null
  }, {
    id: 'COU',
    name: 'Unidad de Valor Real',
    fractionSize: 2,
    symbol: null,
    uniqSymbol: null
  }, {
    id: 'CRC',
    name: 'Cost Rican Colon',
    fractionSize: 2,
    symbol: {
      grapheme: '₡',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: '₡',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'CUC',
    name: 'Peso Convertible',
    fractionSize: 2,
    symbol: null,
    uniqSymbol: null
  }, {
    id: 'CUP',
    name: 'Cuban Peso',
    fractionSize: 2,
    symbol: {
      grapheme: '$MN',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: '$MN',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'CVE',
    name: 'Cabo Verde Escudo',
    fractionSize: 2,
    symbol: null,
    uniqSymbol: null
  }, {
    id: 'CZK',
    name: 'Czech Koruna',
    fractionSize: 2,
    symbol: {
      grapheme: 'Kč',
      template: '1 $',
      rtl: false
    },
    uniqSymbol: {
      grapheme: 'Kč',
      template: '1 $',
      rtl: false
    }
  }, {
    id: 'DJF',
    name: 'Djibouti Franc',
    fractionSize: 0,
    symbol: null,
    uniqSymbol: null
  }, {
    id: 'DKK',
    name: 'Danish Krone',
    fractionSize: 2,
    symbol: {
      grapheme: 'kr',
      template: '1 $',
      rtl: false
    },
    uniqSymbol: null
  }, {
    id: 'DOP',
    name: 'Dominican Peso',
    fractionSize: 2,
    symbol: {
      grapheme: 'RD$',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: 'RD$',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'DZD',
    name: 'Algerian Dinar',
    fractionSize: 2,
    symbol: {
      grapheme: '.د.ج',
      template: '1 $',
      rtl: true
    },
    uniqSymbol: {
      grapheme: '.د.ج',
      template: '1 $',
      rtl: true
    }
  }, {
    id: 'EEK',
    name: 'Estonian Kroon',
    fractionSize: 2,
    symbol: {
      grapheme: 'kr',
      template: '$1',
      rtl: false
    },
    uniqSymbol: null
  }, {
    id: 'EGP',
    name: 'Egyptian Pound',
    fractionSize: 2,
    symbol: {
      grapheme: '£',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: '.ج.م',
      template: '1 $',
      rtl: true
    }
  }, {
    id: 'ERN',
    name: 'Nakfa',
    fractionSize: 2,
    symbol: null,
    uniqSymbol: null
  }, {
    id: 'ETB',
    name: 'Ethiopian Birr',
    fractionSize: 2,
    symbol: null,
    uniqSymbol: null
  }, {
    id: 'EUR',
    name: 'Euro',
    fractionSize: 2,
    symbol: {
      grapheme: '€',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: '€',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'FJD',
    name: 'Fiji Dollar',
    fractionSize: 2,
    symbol: {
      grapheme: '$',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: 'FJ$',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'FKP',
    name: 'Falkland Islands Pound',
    fractionSize: 2,
    symbol: {
      grapheme: '£',
      template: '$1',
      rtl: false
    },
    uniqSymbol: null
  }, {
    id: 'GBP',
    name: 'Pound Sterling',
    fractionSize: 2,
    symbol: {
      grapheme: '£',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: '£',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'GEL',
    name: 'Lari',
    fractionSize: 2,
    symbol: null,
    uniqSymbol: null
  }, {
    id: 'GGP',
    name: 'Guernsey Pound',
    fractionSize: 2,
    symbol: {
      grapheme: '£',
      template: '$1',
      rtl: false
    },
    uniqSymbol: null
  }, {
    id: 'GHC',
    name: 'Ghanaian Cedi',
    fractionSize: 2,
    symbol: {
      grapheme: '¢',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: '¢',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'GHS',
    name: 'Ghan Cedi',
    fractionSize: 2,
    symbol: null,
    uniqSymbol: null
  }, {
    id: 'GIP',
    name: 'Gibraltar Pound',
    fractionSize: 2,
    symbol: {
      grapheme: '£',
      template: '$1',
      rtl: false
    },
    uniqSymbol: null
  }, {
    id: 'GMD',
    name: 'Dalasi',
    fractionSize: 2,
    symbol: null,
    uniqSymbol: null
  }, {
    id: 'GNF',
    name: 'Guine Franc',
    fractionSize: 0,
    symbol: null,
    uniqSymbol: null
  }, {
    id: 'GTQ',
    name: 'Quetzal',
    fractionSize: 2,
    symbol: {
      grapheme: 'Q',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: 'Q',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'GYD',
    name: 'Guyan Dollar',
    fractionSize: 2,
    symbol: {
      grapheme: '$',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: 'GY$',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'HKD',
    name: 'Hong Kong Dollar',
    fractionSize: 2,
    symbol: {
      grapheme: '$',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: 'HK$',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'HNL',
    name: 'Lempira',
    fractionSize: 2,
    symbol: {
      grapheme: 'L',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: 'L',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'HRK',
    name: 'Croatian Kuna',
    fractionSize: 2,
    symbol: {
      grapheme: 'kn',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: 'kn',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'HTG',
    name: 'Gourde',
    fractionSize: 2,
    symbol: null,
    uniqSymbol: null
  }, {
    id: 'HUF',
    name: 'Forint',
    fractionSize: 0,
    symbol: {
      grapheme: 'Ft',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: 'Ft',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'IDR',
    name: 'Rupiah',
    fractionSize: 2,
    symbol: {
      grapheme: 'Rp',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: 'Rp',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'ILS',
    name: 'New Israeli Sheqel',
    fractionSize: 2,
    symbol: {
      grapheme: '₪',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: '₪',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'IMP',
    name: 'Manx Pound',
    fractionSize: 2,
    symbol: {
      grapheme: '£',
      template: '$1',
      rtl: false
    },
    uniqSymbol: null
  }, {
    id: 'INR',
    name: 'Indian Rupee',
    fractionSize: 2,
    symbol: {
      grapheme: '₹',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: '₹',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'IQD',
    name: 'Iraqi Dinar',
    fractionSize: 3,
    symbol: {
      grapheme: '.د.ع',
      template: '1 $',
      rtl: true
    },
    uniqSymbol: {
      grapheme: '.د.ع',
      template: '1 $',
      rtl: true
    }
  }, {
    id: 'IRR',
    name: 'Iranian Rial',
    fractionSize: 0,
    symbol: {
      grapheme: '﷼',
      template: '1 $',
      rtl: true
    },
    uniqSymbol: {
      grapheme: '﷼',
      template: '1 $',
      rtl: true
    }
  }, {
    id: 'ISK',
    name: 'Iceland Krona',
    fractionSize: 2,
    symbol: {
      grapheme: 'kr',
      template: '$1',
      rtl: false
    },
    uniqSymbol: null
  }, {
    id: 'JEP',
    name: 'Jersey Pound',
    fractionSize: 2,
    symbol: {
      grapheme: '£',
      template: '$1',
      rtl: false
    },
    uniqSymbol: null
  }, {
    id: 'JMD',
    name: 'Jamaican Dollar',
    fractionSize: 2,
    symbol: {
      grapheme: 'J$',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: 'J$',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'JOD',
    name: 'Jordanian Dinar',
    fractionSize: 3,
    symbol: {
      grapheme: '.د.إ',
      template: '1 $',
      rtl: true
    },
    uniqSymbol: null
  }, {
    id: 'JPY',
    name: 'Yen',
    fractionSize: 0,
    symbol: {
      grapheme: '¥',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: '¥',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'KES',
    name: 'Kenyan Shilling',
    fractionSize: 2,
    symbol: {
      grapheme: 'KSh',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: 'KSh',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'KGS',
    name: 'Som',
    fractionSize: 2,
    symbol: {
      grapheme: 'сом',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: 'сом',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'KHR',
    name: 'Riel',
    fractionSize: 2,
    symbol: {
      grapheme: '៛',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: '៛',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'KMF',
    name: 'Comoro Franc',
    fractionSize: 0,
    symbol: null,
    uniqSymbol: null
  }, {
    id: 'KPW',
    name: 'North Korean Won',
    fractionSize: 0,
    symbol: {
      grapheme: '₩',
      template: '$1',
      rtl: false
    },
    uniqSymbol: null
  }, {
    id: 'KRW',
    name: 'Won',
    fractionSize: 0,
    symbol: {
      grapheme: '₩',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: '₩',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'KWD',
    name: 'Kuwaiti Dinar',
    fractionSize: 3,
    symbol: {
      grapheme: '.د.ك',
      template: '1 $',
      rtl: true
    },
    uniqSymbol: {
      grapheme: '.د.ك',
      template: '1 $',
      rtl: true
    }
  }, {
    id: 'KYD',
    name: 'Cayman Islands Dollar',
    fractionSize: 2,
    symbol: {
      grapheme: '$',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: 'CI$',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'KZT',
    name: 'Tenge',
    fractionSize: 2,
    symbol: {
      grapheme: '₸',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: '₸',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'LAK',
    name: 'Kip',
    fractionSize: 2,
    symbol: {
      grapheme: '₭',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: '₭',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'LBP',
    name: 'Lebanese Pound',
    fractionSize: 2,
    symbol: {
      grapheme: '£',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: '.ل.ل',
      template: '1 $',
      rtl: true
    }
  }, {
    id: 'LKR',
    name: 'Sri Lank Rupee',
    fractionSize: 2,
    symbol: {
      grapheme: '₨',
      template: '$1',
      rtl: false
    },
    uniqSymbol: null
  }, {
    id: 'LRD',
    name: 'Liberian Dollar',
    fractionSize: 2,
    symbol: {
      grapheme: '$',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: 'L$',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'LSL',
    name: 'Loti',
    fractionSize: 2,
    symbol: null,
    uniqSymbol: null
  }, {
    id: 'LTL',
    name: 'Lithuanian Litas',
    fractionSize: 2,
    symbol: {
      grapheme: 'Lt',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: 'Lt',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'LVL',
    name: 'Latvian Lats',
    fractionSize: 2,
    symbol: {
      grapheme: 'Ls',
      template: '1 $',
      rtl: false
    },
    uniqSymbol: {
      grapheme: 'Ls',
      template: '1 $',
      rtl: false
    }
  }, {
    id: 'LYD',
    name: 'Libyan Dinar',
    fractionSize: 3,
    symbol: {
      grapheme: '.د.ل',
      template: '1 $',
      rtl: true
    },
    uniqSymbol: {
      grapheme: '.د.ل',
      template: '1 $',
      rtl: true
    }
  }, {
    id: 'MAD',
    name: 'Moroccan Dirham',
    fractionSize: 2,
    symbol: {
      grapheme: '.د.م',
      template: '1 $',
      rtl: true
    },
    uniqSymbol: {
      grapheme: '.د.م',
      template: '1 $',
      rtl: true
    }
  }, {
    id: 'MDL',
    name: 'Moldovan Leu',
    fractionSize: 2,
    symbol: null,
    uniqSymbol: null
  }, {
    id: 'MGA',
    name: 'Malagasy ariary',
    fractionSize: 1,
    symbol: null,
    uniqSymbol: null
  }, {
    id: 'MKD',
    name: 'Denar',
    fractionSize: 2,
    symbol: {
      grapheme: 'ден',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: 'ден',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'MMK',
    name: 'Kyat',
    fractionSize: 2,
    symbol: null,
    uniqSymbol: null
  }, {
    id: 'MNT',
    name: 'Tugrik',
    fractionSize: 2,
    symbol: {
      grapheme: '₮',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: '₮',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'MOP',
    name: 'Pataca',
    fractionSize: 2,
    symbol: null,
    uniqSymbol: null
  }, {
    id: 'MRO',
    name: 'Ouguiya',
    fractionSize: 2,
    symbol: null,
    uniqSymbol: null
  }, {
    id: 'MUR',
    name: 'Mauritius Rupee',
    fractionSize: 2,
    symbol: {
      grapheme: '₨',
      template: '$1',
      rtl: false
    },
    uniqSymbol: null
  }, {
    id: 'MVR',
    name: 'Rufiyaa',
    fractionSize: 2,
    symbol: null,
    uniqSymbol: null
  }, {
    id: 'MWK',
    name: 'Kwacha',
    fractionSize: 2,
    symbol: null,
    uniqSymbol: null
  }, {
    id: 'MXN',
    name: 'Mexican Peso',
    fractionSize: 2,
    symbol: {
      grapheme: '$',
      template: '$1',
      rtl: false
    },
    uniqSymbol: null
  }, {
    id: 'MXV',
    name: 'Mexican Unidad de Inversion (UDI)',
    fractionSize: 2,
    symbol: null,
    uniqSymbol: null
  }, {
    id: 'MYR',
    name: 'Malaysian Ringgit',
    fractionSize: 2,
    symbol: {
      grapheme: 'RM',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: 'RM',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'MZN',
    name: 'Mozambique Metical',
    fractionSize: 2,
    symbol: {
      grapheme: 'MT',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: 'MT',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'NAD',
    name: 'Namibi Dollar',
    fractionSize: 2,
    symbol: {
      grapheme: '$',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: 'N$',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'NGN',
    name: 'Naira',
    fractionSize: 2,
    symbol: {
      grapheme: '₦',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: '₦',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'NIO',
    name: 'Cordob Oro',
    fractionSize: 2,
    symbol: {
      grapheme: 'C$',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: 'C$',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'NOK',
    name: 'Norwegian Krone',
    fractionSize: 2,
    symbol: {
      grapheme: 'kr',
      template: '1 $',
      rtl: false
    },
    uniqSymbol: null
  }, {
    id: 'NPR',
    name: 'Nepalese Rupee',
    fractionSize: 2,
    symbol: {
      grapheme: '₨',
      template: '$1',
      rtl: false
    },
    uniqSymbol: null
  }, {
    id: 'NZD',
    name: 'New Zealand Dollar',
    fractionSize: 2,
    symbol: {
      grapheme: '$',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: 'NZ$',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'OMR',
    name: 'Rial Omani',
    fractionSize: 3,
    symbol: {
      grapheme: '﷼',
      template: '1 $',
      rtl: true
    },
    uniqSymbol: {
      grapheme: '.ر.ع',
      template: '1 $',
      rtl: true
    }
  }, {
    id: 'PAB',
    name: 'Balboa',
    fractionSize: 2,
    symbol: {
      grapheme: 'B/.',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: 'B/.',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'PEN',
    name: 'Nuevo Sol',
    fractionSize: 2,
    symbol: {
      grapheme: 'S/',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: 'S/',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'PGK',
    name: 'Kina',
    fractionSize: 2,
    symbol: null,
    uniqSymbol: null
  }, {
    id: 'PHP',
    name: 'Philippine Peso',
    fractionSize: 2,
    symbol: {
      grapheme: '₱',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: '₱',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'PKR',
    name: 'Pakistan Rupee',
    fractionSize: 2,
    symbol: {
      grapheme: '₨',
      template: '$1',
      rtl: false
    },
    uniqSymbol: null
  }, {
    id: 'PLN',
    name: 'Zloty',
    fractionSize: 2,
    symbol: {
      grapheme: 'zł',
      template: '1 $',
      rtl: false
    },
    uniqSymbol: {
      grapheme: 'zł',
      template: '1 $',
      rtl: false
    }
  }, {
    id: 'PYG',
    name: 'Guarani',
    fractionSize: 0,
    symbol: {
      grapheme: 'Gs',
      template: '1$',
      rtl: false
    },
    uniqSymbol: {
      grapheme: 'Gs',
      template: '1$',
      rtl: false
    }
  }, {
    id: 'QAR',
    name: 'Qatari Rial',
    fractionSize: 2,
    symbol: {
      grapheme: '﷼',
      template: '1 $',
      rtl: true
    },
    uniqSymbol: {
      grapheme: '.ر.ق',
      template: '1 $',
      rtl: true
    }
  }, {
    id: 'RON',
    name: 'New Romanian Leu',
    fractionSize: 2,
    symbol: {
      grapheme: 'lei',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: 'lei',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'RSD',
    name: 'Serbian Dinar',
    fractionSize: 2,
    symbol: {
      grapheme: 'Дин.',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: 'Дин.',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'RUB',
    name: 'Russian Ruble',
    fractionSize: 2,
    symbol: {
      grapheme: '₽',
      template: '1 $',
      rtl: false
    },
    uniqSymbol: {
      grapheme: '₽',
      template: '1 $',
      rtl: false
    }
  }, {
    id: 'RUR',
    name: 'Russian Ruble',
    fractionSize: 2,
    symbol: {
      grapheme: '₽',
      template: '1 $',
      rtl: false
    },
    uniqSymbol: {
      grapheme: '₽',
      template: '1 $',
      rtl: false
    }
  }, {
    id: 'RWF',
    name: 'Rwand Franc',
    fractionSize: 0,
    symbol: null,
    uniqSymbol: null
  }, {
    id: 'SAR',
    name: 'Saudi Riyal',
    fractionSize: 2,
    symbol: {
      grapheme: '﷼',
      template: '1 $',
      rtl: true
    },
    uniqSymbol: {
      grapheme: '.ر.س',
      template: '1 $',
      rtl: true
    }
  }, {
    id: 'SBD',
    name: 'Solomon Islands Dollar',
    fractionSize: 2,
    symbol: {
      grapheme: '$',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: 'SI$',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'SCR',
    name: 'Seychelles Rupee',
    fractionSize: 2,
    symbol: {
      grapheme: '₨',
      template: '$1',
      rtl: false
    },
    uniqSymbol: null
  }, {
    id: 'SDG',
    name: 'Sudanese Pound',
    fractionSize: 2,
    symbol: null,
    uniqSymbol: null
  }, {
    id: 'SEK',
    name: 'Swedish Krona',
    fractionSize: 2,
    symbol: {
      grapheme: 'kr',
      template: '1 $',
      rtl: false
    },
    uniqSymbol: null
  }, {
    id: 'SGD',
    name: 'Singapore Dollar',
    fractionSize: 2,
    symbol: {
      grapheme: '$',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: 'S$',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'SHP',
    name: 'Saint Helen Pound',
    fractionSize: 2,
    symbol: {
      grapheme: '£',
      template: '$1',
      rtl: false
    },
    uniqSymbol: null
  }, {
    id: 'SLL',
    name: 'Leone',
    fractionSize: 2,
    symbol: null,
    uniqSymbol: null
  }, {
    id: 'SOS',
    name: 'Somali Shilling',
    fractionSize: 2,
    symbol: {
      grapheme: 'S',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: 'S',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'SRD',
    name: 'Surinam Dollar',
    fractionSize: 2,
    symbol: {
      grapheme: '$',
      template: '$1',
      rtl: false
    },
    uniqSymbol: null
  }, {
    id: 'SSP',
    name: 'South Sudanese Pound',
    fractionSize: 2,
    symbol: null,
    uniqSymbol: null
  }, {
    id: 'STD',
    name: 'Dobra',
    fractionSize: 2,
    symbol: null,
    uniqSymbol: null
  }, {
    id: 'SVC',
    name: 'El Salvador Colon',
    fractionSize: 2,
    symbol: {
      grapheme: '$',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: 'C',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'SYP',
    name: 'Syrian Pound',
    fractionSize: 2,
    symbol: {
      grapheme: '£',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: '.ل.س',
      template: '1 $',
      rtl: true
    }
  }, {
    id: 'SZL',
    name: 'Lilangeni',
    fractionSize: 2,
    symbol: null,
    uniqSymbol: null
  }, {
    id: 'THB',
    name: 'Baht',
    fractionSize: 2,
    symbol: {
      grapheme: '฿',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: '฿',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'TJS',
    name: 'Somoni',
    fractionSize: 2,
    symbol: null,
    uniqSymbol: null
  }, {
    id: 'TMT',
    name: 'Turkmenistan New Manat',
    fractionSize: 2,
    symbol: null,
    uniqSymbol: null
  }, {
    id: 'TND',
    name: 'Tunisian Dinar',
    fractionSize: 3,
    symbol: {
      grapheme: '.د.ت',
      template: '1 $',
      rtl: true
    },
    uniqSymbol: {
      grapheme: '.د.ت',
      template: '1 $',
      rtl: true
    }
  }, {
    id: 'TOP',
    name: 'Pa’anga',
    fractionSize: 2,
    symbol: null,
    uniqSymbol: null
  }, {
    id: 'TRL',
    name: 'Turkish Lira',
    fractionSize: 2,
    symbol: {
      grapheme: '₤',
      template: '$1',
      rtl: false
    },
    uniqSymbol: null
  }, {
    id: 'TRY',
    name: 'Turkish Lira',
    fractionSize: 2,
    symbol: {
      grapheme: '₺',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: '₺',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'TTD',
    name: 'Trinidad and Tobago Dollar',
    fractionSize: 2,
    symbol: {
      grapheme: 'TT$',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: 'TT$',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'TWD',
    name: 'New Taiwan Dollar',
    fractionSize: 0,
    symbol: {
      grapheme: 'NT$',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: 'NT$',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'TZS',
    name: 'Tanzanian Shilling',
    fractionSize: 0,
    symbol: {
      grapheme: 'TSh',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: 'TSh',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'UAH',
    name: 'Hryvnia',
    fractionSize: 2,
    symbol: {
      grapheme: '₴',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: '₴',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'UGX',
    name: 'Ugand Shilling',
    fractionSize: 0,
    symbol: {
      grapheme: 'USh',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: 'USh',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'USD',
    name: 'US Dollar',
    fractionSize: 2,
    symbol: {
      grapheme: '$',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: '$',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'USN',
    name: 'US Dollar (Next day)',
    fractionSize: 2,
    symbol: null,
    uniqSymbol: null
  }, {
    id: 'UYI',
    name: 'Uruguay Peso en Unidades Indexadas (URUIURUI)',
    fractionSize: 0,
    symbol: null,
    uniqSymbol: null
  }, {
    id: 'UYU',
    name: 'Peso Uruguayo',
    fractionSize: 0,
    symbol: {
      grapheme: '$U',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: '$U',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'UZS',
    name: 'Uzbekistan Sum',
    fractionSize: 2,
    symbol: {
      grapheme: 'so’m',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: 'so’m',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'VEF',
    name: 'Bolivar',
    fractionSize: 2,
    symbol: {
      grapheme: 'Bs',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: 'Bs',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'VES',
    name: 'Bolivar',
    fractionSize: 2,
    symbol: {
      grapheme: 'Bs',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: 'Bs',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'VND',
    name: 'Dong',
    fractionSize: 0,
    symbol: {
      grapheme: '₫',
      template: '1 $',
      rtl: false
    },
    uniqSymbol: {
      grapheme: '₫',
      template: '1 $',
      rtl: false
    }
  }, {
    id: 'VUV',
    name: 'Vatu',
    fractionSize: 0,
    symbol: null,
    uniqSymbol: null
  }, {
    id: 'WST',
    name: 'Tala',
    fractionSize: 2,
    symbol: null,
    uniqSymbol: null
  }, {
    id: 'XAF',
    name: 'CFA Franc BEAC',
    fractionSize: 0,
    symbol: {
      grapheme: 'FCFA',
      template: '1 $',
      rtl: false
    },
    uniqSymbol: {
      grapheme: 'FCFA',
      template: '1 $',
      rtl: false
    }
  }, {
    id: 'XCD',
    name: 'East Caribbean Dollar',
    fractionSize: 2,
    symbol: {
      grapheme: '$',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: 'EC$',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'XDR',
    name: 'SDR (Special Drawing Right)',
    fractionSize: 0,
    symbol: null,
    uniqSymbol: null
  }, {
    id: 'XOF',
    name: 'CFA Franc BCEAO',
    fractionSize: 0,
    symbol: {
      grapheme: 'CFA',
      template: '1 $',
      rtl: false
    },
    uniqSymbol: {
      grapheme: 'CFA',
      template: '1 $',
      rtl: false
    }
  }, {
    id: 'XPF',
    name: 'CFP Franc',
    fractionSize: 0,
    symbol: null,
    uniqSymbol: null
  }, {
    id: 'XSU',
    name: 'Sucre',
    fractionSize: 0,
    symbol: null,
    uniqSymbol: null
  }, {
    id: 'XUA',
    name: 'ADB Unit of Account',
    fractionSize: 0,
    symbol: null,
    uniqSymbol: null
  }, {
    id: 'YER',
    name: 'Yemeni Rial',
    fractionSize: 2,
    symbol: {
      grapheme: '﷼',
      template: '1 $',
      rtl: true
    },
    uniqSymbol: {
      grapheme: '.ر.ي',
      template: '1 $',
      rtl: true
    }
  }, {
    id: 'ZAR',
    name: 'Rand',
    fractionSize: 2,
    symbol: {
      grapheme: 'R',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: 'R',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'ZMW',
    name: 'Zambian Kwacha',
    fractionSize: 2,
    symbol: null,
    uniqSymbol: null
  }, {
    id: 'ZWD',
    name: 'Zimbabwe Dollar',
    fractionSize: 2,
    symbol: {
      grapheme: 'Z$',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: 'Z$',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'ZWL',
    name: 'Zimbabwe Dollar',
    fractionSize: 2,
    symbol: null,
    uniqSymbol: null
  }, {
    id: 'BTC',
    name: 'BTC',
    fractionSize: 4,
    symbol: {
      grapheme: '₿',
      template: '1 $',
      rtl: false
    },
    uniqSymbol: {
      grapheme: '₿',
      template: '1 $',
      rtl: false
    }
  }, {
    id: 'ETH',
    name: 'ETH',
    fractionSize: 4,
    symbol: {
      grapheme: 'Ξ',
      template: '1 $',
      rtl: false
    },
    uniqSymbol: {
      grapheme: 'Ξ',
      template: '1 $',
      rtl: false
    }
  }, {
    id: 'LTC',
    name: 'LTC',
    fractionSize: 4,
    symbol: {
      grapheme: 'Ł',
      template: '1 $',
      rtl: false
    },
    uniqSymbol: {
      grapheme: 'Ł',
      template: '1 $',
      rtl: false
    }
  }];
}

function formatCurrency(input, currency, numberFormat) {
  if (currency === void 0) {
    currency = 'EUR';
  }

  if (numberFormat === void 0) {
    numberFormat = 'comma';
  }

  var currencies = getCurrencies();
  var currencyObject = currencies.find(function (x) {
    return x.id === currency;
  });

  if (!currencyObject) {
    throw new Error('Currency not found');
  }

  var symbol = currencyObject.symbol,
      fractionSize = currencyObject.fractionSize;
  var result;

  if (symbol) {
    var grapheme = symbol.grapheme,
        template = symbol.template;
    var format = template.replace('$', '%s').replace('1', '%v');
    result = {
      symbol: grapheme,
      format: format,
      fractionSize: fractionSize
    };
  } else {
    result = {
      symbol: currencyObject.id,
      fractionSize: fractionSize
    };
  }

  switch (numberFormat) {
    case 'dot':
      return accounting.formatMoney(input, _extends({}, result, {
        decimal: '.',
        thousand: ','
      }));

    case 'space':
      return accounting.formatMoney(input, _extends({}, result, {
        decimal: ',',
        thousand: ' '
      }));

    case 'comma':
    default:
      return accounting.formatMoney(input, _extends({}, result, {
        decimal: ',',
        thousand: '.'
      }));
  }
}

function unformatCurrency(input, numberFormat) {
  if (numberFormat === void 0) {
    numberFormat = 'comma';
  }

  switch (numberFormat) {
    case 'dot':
      return accounting.unformat(input, '.');

    case 'space':
      return accounting.unformat(input, ',');

    case 'comma':
    default:
      return accounting.unformat(input, ',');
  }
}

var LocaleDate = /*#__PURE__*/function () {
  function LocaleDate(input, dateObject) {
    var utc = dateFns.fromUnixTime(input);
    this.date = dateFnsTz.utcToZonedTime(utc, dateObject.timezone);
    this.dateObject = dateObject;
  }

  var _proto = LocaleDate.prototype;

  _proto.toDate = function toDate() {
    var _this$dateObject = this.dateObject,
        dateFormat = _this$dateObject.dateFormat,
        timezone = _this$dateObject.timezone;
    return dateFnsTz.format(this.date, dateFormat, {
      timeZone: timezone
    });
  };

  return LocaleDate;
}();

var TcDate = /*#__PURE__*/function () {
  function TcDate(input) {
    if (!input) {
      var utc = new Date();
      this.internalDate = dateFns.getUnixTime(utc);
    } else {
      var _utc = new Date(input);

      this.internalDate = dateFns.getUnixTime(_utc);
    }
  }

  var _proto = TcDate.prototype;

  _proto.toDate = function toDate() {
    return this.internalDate;
  };

  _proto.add = function add(amount, type) {
    switch (type) {
      case 'milliseconds':
      case 'millisecond':
      case 'ms':
        this.date = dateFns.addMilliseconds(this.date, amount);
        break;

      case 'seconds':
      case 'second':
      case 's':
        this.date = dateFns.addSeconds(this.date, amount);
        break;

      case 'minutes':
      case 'minute':
      case 'm':
        this.date = dateFns.addMinutes(this.date, amount);
        break;

      case 'hours':
      case 'hour':
      case 'h':
        this.date = dateFns.addHours(this.date, amount);
        break;

      case 'days':
      case 'day':
      case 'd':
        this.date = dateFns.addDays(this.date, amount);
        break;

      case 'weeks':
      case 'week':
      case 'w':
        this.date = dateFns.addWeeks(this.date, amount);
        break;

      case 'months':
      case 'month':
      case 'M':
        this.date = dateFns.addMonths(this.date, amount);
        break;

      case 'quarters':
      case 'quarter':
      case 'q':
        this.date = dateFns.addQuarters(this.date, amount);
        break;

      case 'years':
      case 'year':
      case 'y':
        this.date = dateFns.addYears(this.date, amount);
        break;
    }

    return this;
  };

  _proto.subtract = function subtract(amount, type) {
    switch (type) {
      case 'milliseconds':
      case 'millisecond':
      case 'ms':
        this.date = dateFns.subMilliseconds(this.date, amount);
        break;

      case 'seconds':
      case 'second':
      case 's':
        this.date = dateFns.subSeconds(this.date, amount);
        break;

      case 'minutes':
      case 'minute':
      case 'm':
        this.date = dateFns.subMinutes(this.date, amount);
        break;

      case 'hours':
      case 'hour':
      case 'h':
        this.date = dateFns.subHours(this.date, amount);
        break;

      case 'days':
      case 'day':
      case 'd':
        this.date = dateFns.subDays(this.date, amount);
        break;

      case 'weeks':
      case 'week':
      case 'w':
        this.date = dateFns.subWeeks(this.date, amount);
        break;

      case 'months':
      case 'month':
      case 'M':
        this.date = dateFns.subMonths(this.date, amount);
        break;

      case 'quarters':
      case 'quarter':
      case 'q':
        this.date = dateFns.subQuarters(this.date, amount);
        break;

      case 'years':
      case 'year':
      case 'y':
        this.date = dateFns.subYears(this.date, amount);
        break;
    }

    return this;
  };

  _proto.diff = function diff(start, type) {
    var difference = dateFns.differenceInSeconds(this.date, start);

    switch (type) {
      case 'seconds':
      case 'second':
        difference = dateFns.differenceInSeconds(this.date, start);
        break;

      case 'minutes':
      case 'minute':
        difference = dateFns.differenceInMinutes(this.date, start);
        break;

      case 'hours':
      case 'hour':
        difference = dateFns.differenceInHours(this.date, start);
        break;

      case 'days':
      case 'day':
        difference = dateFns.differenceInDays(this.date, start);
        break;

      case 'weeks':
      case 'week':
        difference = dateFns.differenceInWeeks(this.date, start);
        break;

      case 'months':
      case 'month':
        difference = dateFns.differenceInMonths(this.date, start);
        break;

      case 'quarters':
      case 'quarter':
        difference = dateFns.differenceInQuarters(this.date, start);
        break;

      case 'years':
      case 'year':
        difference = dateFns.differenceInYears(this.date, start);
        break;
    }

    return difference;
  };

  _proto.startOf = function startOf(type, weekStartDay) {
    switch (type) {
      case 'seconds':
        this.date = dateFns.startOfSecond(this.date);
        break;

      case 'minutes':
        this.date = dateFns.startOfMinute(this.date);
        break;

      case 'hours':
        this.date = dateFns.startOfHour(this.date);
        break;

      case 'day':
        this.date = dateFns.startOfDay(this.date);
        break;

      case 'week':
        this.date = dateFns.startOfWeek(this.date, {
          weekStartsOn: weekStartDay
        });
        break;

      case 'month':
        this.date = dateFns.startOfMonth(this.date);
        break;

      case 'quarter':
        this.date = dateFns.startOfQuarter(this.date);
        break;

      case 'year':
        this.date = dateFns.startOfYear(this.date);
        break;
    }

    return this;
  };

  _proto.endOf = function endOf(type, weekStartDay) {
    switch (type) {
      case 'seconds':
        this.date = dateFns.endOfSecond(this.date);
        break;

      case 'minutes':
        this.date = dateFns.endOfMinute(this.date);
        break;

      case 'hours':
        this.date = dateFns.endOfHour(this.date);
        break;

      case 'day':
        this.date = dateFns.endOfDay(this.date);
        break;

      case 'week':
        this.date = dateFns.endOfWeek(this.date, {
          weekStartsOn: weekStartDay
        });
        break;

      case 'month':
        this.date = dateFns.endOfMonth(this.date);
        break;

      case 'quarter':
        this.date = dateFns.endOfQuarter(this.date);
        break;

      case 'year':
        this.date = dateFns.endOfYear(this.date);
        break;
    }

    return this;
  };

  _proto.weekday = function weekday() {
    return dateFns.getDay(this.date);
  };

  _proto.weekdayToDate = function weekdayToDate(day, weekStartDay) {
    return dateFns.setDay(this.date, day, {
      weekStartsOn: weekStartDay
    });
  };

  _proto.week = function week(weekStartDay) {
    return dateFns.getWeek(this.date, {
      weekStartsOn: weekStartDay
    });
  };

  _proto.isSame = function isSame(dateToCheck, type, weekStartDay) {
    switch (type) {
      case 'day':
        return dateFns.isSameDay(this.date, dateToCheck);

      case 'week':
        return dateFns.isSameWeek(this.date, dateToCheck, {
          weekStartsOn: weekStartDay
        });

      case 'month':
        return dateFns.isSameMonth(this.date, dateToCheck);

      case 'quarter':
        return dateFns.isSameQuarter(this.date, dateToCheck);

      case 'year':
        return dateFns.isSameYear(this.date, dateToCheck);

      default:
        return false;
    }
  };

  _proto.isBetween = function isBetween(_ref) {
    var start = _ref.start,
        end = _ref.end;
    return dateFns.isWithinInterval(this.date, {
      start: start,
      end: end
    });
  };

  _proto.isAfter = function isAfter(dateToCheck) {
    return dateFns.isAfter(this.date, dateToCheck);
  };

  _proto.isValid = function isValid() {
    return dateFns.isValid(this.date);
  };

  _proto.set = function set(amount, type) {
    switch (type) {
      case 'second':
      case 'seconds':
        this.date = dateFns.setSeconds(this.date, amount);
        break;

      case 'minute':
      case 'minutes':
        this.date = dateFns.setMinutes(this.date, amount);
        break;

      case 'hour':
      case 'hours':
        this.date = dateFns.setHours(this.date, amount);
    }

    return this;
  };

  _proto.daysInMonth = function daysInMonth() {
    return dateFns.getDaysInMonth(this.date);
  };

  _proto.toISOString = function toISOString() {
    return this.date.toISOString();
  };

  _proto.interval = function interval(start, end) {
    return dateFns.eachDayOfInterval({
      start: start,
      end: end
    });
  };

  _proto.weekOfYear = function weekOfYear(date) {
    return dateFns.getWeek(date);
  };

  _createClass(TcDate, [{
    key: "date",
    get: function get() {
      return dateFns.fromUnixTime(this.internalDate);
    },
    set: function set(value) {
      this.internalDate = dateFns.getUnixTime(value);
    }
  }]);

  return TcDate;
}();

function formatDate(input, dateObject) {
  var unix = new TcDate(input).toDate();
  return new LocaleDate(unix, dateObject).toDate();
}

function formatFloat(input, max24) {
  if (!input) {
    return 0;
  }

  var _float = 0.0;
  var isNegative = false; // replace comma for dot

  input = input.replace(',', '.'); // is negative value

  if (input.includes('-')) {
    input = input.replace('-', '');
    isNegative = true;
  }

  if (input.includes(':')) {
    // 01:30    = 1.5 hour
    // 1:30     = 1.5 hour
    // :30      = 0.5 hour
    var h = parseInt(input.split(':')[0], 10) || 0;
    var m = parseFloat(input.split(':')[1]) / 60;
    _float = h + m;
  } else if (!input.includes('.') && (input.length === 3 || input.length === 4)) {
    // 0130     = 1.5 hour
    // 130      = 1.5 hour
    input = input.replace(/^0/, '');

    if (input.length === 3) {
      var _h = parseInt(input[0], 10);

      var _m = parseFloat(input[1] + input[2]) / 60;

      _float = _h + _m;
    } else {
      var _h2 = parseInt(input[0] + input[1], 10);

      var _m2 = parseFloat(input[2] + input[3]) / 60;

      _float = _h2 + _m2;
    }
  } else {
    // 1.5      = 1.5 hour
    // 1,5      = 1.5 hour
    // .5       = 0.5 hour
    // ,5       = 0.5 hour
    // 24       = 24 hour
    // 1        = 1 hour
    _float = parseFloat(input);
  }

  if (isNaN(_float)) {
    _float = 0;
  }

  if (max24 && _float > 24) {
    _float = 24;
  }

  if (isNegative) {
    _float = _float * -1;
  }

  return _float;
}

function formatNumber(input, precision, numberFormat) {
  if (precision === void 0) {
    precision = 2;
  }

  if (numberFormat === void 0) {
    numberFormat = 'comma';
  }

  switch (numberFormat) {
    case 'dot':
      return accounting.formatNumber(input, precision, ',', '.');

    case 'space':
      return accounting.formatNumber(input, precision, ',', ' ');

    case 'comma':
    default:
      return accounting.formatNumber(input, precision, '.', ',');
  }
}

function formatDistance(input, distance, symbol, precision, numberFormat) {
  if (symbol === void 0) {
    symbol = true;
  }

  if (precision === void 0) {
    precision = 2;
  }

  if (numberFormat === void 0) {
    numberFormat = 'comma';
  }

  var converted;

  if (distance === 'mi') {
    converted = input * 0.000621371192;
  } else {
    converted = input / 1000;
  }

  var formatted = formatNumber(converted, precision, numberFormat);

  if (!symbol) {
    return formatted;
  }

  return distance === 'km' ? formatted + " KM" : formatted + " mi";
}

function formatTime(seconds, format) {
  if (format === void 0) {
    format = 'HH:mm:ss';
  }

  if (isNaN(seconds)) {
    seconds = 0;
  }

  var time = '';
  var isNegative = false;

  if (seconds < 0) {
    isNegative = true;
    seconds = Math.abs(seconds);
  }

  if (format === 'HH:mm:ss') {
    var hour = Math.floor(seconds / 3600);
    var minute = Math.floor((seconds - hour * 3600) / 60);
    var second = Math.floor(seconds - hour * 3600 - minute * 60);
    var formatedHour = hour < 10 ? "0" + hour : hour;

    if (minute < 10) {
      time = formatedHour + ":0" + minute;
    } else {
      time = formatedHour + ":" + minute;
    }

    if (second < 10) {
      time = time + ":0" + second;
    } else {
      time = time + ":" + second;
    }
  } else if (format === 'HH:mm') {
    var _hour = Math.floor(seconds / 3600);

    var _minute = Math.round((seconds - _hour * 3600) / 60);

    var _formatedHour = _hour < 10 ? "0" + _hour : _hour;

    if (_minute < 10) {
      time = _formatedHour + ":0" + _minute;
    } else {
      time = _formatedHour + ":" + _minute;
    }
  } else if (format === 'decimal') {
    time = formatNumber(seconds / 3600);
  }

  if (isNegative) {
    time = "-" + time;
  }

  return time;
}

function formatUppercase(input) {
  return "" + input.charAt(0).toUpperCase() + input.slice(1);
}

function formatDateInput(input, dateFormat, date) {
  var _float = formatFloat(input, true);

  var time = formatTime(_float * 3600, 'HH:mm');
  var timeArray = time.split(':');
  var hours = parseInt(timeArray[0], 10);
  var minutes = parseInt(timeArray[1], 10);
  var unixDate = new TcDate(date).set(hours, 'hours').set(minutes, 'minutes').set(0, 'seconds').set(0, 'milliseconds').toDate();
  var formatted = new LocaleDate(unixDate, dateFormat).toDate();
  return formatted;
}

function cloneObject(obj) {
  if (!obj) {
    return null;
  }

  return JSON.parse(JSON.stringify(obj));
}

function dynamicSort(property) {
  var sortOrder = 1;

  if (property[0] === '-') {
    sortOrder = -1;
    property = property.substr(1);
  }

  return function (a, b) {
    if (a[property] < b[property]) {
      return -1 * sortOrder;
    }

    if (a[property] > b[property]) {
      return 1 * sortOrder;
    }

    return 0;
  };
}

function globalVarExists(nameOfVariable) {
  return nameOfVariable in window;
}

function dynamicSortMultiple(props) {
  return function (obj1, obj2) {
    var i = 0;
    var result = 0;

    while (result === 0 && i < props.length) {
      result = dynamicSort(props[i])(obj1, obj2);
      i++;
    }

    return result;
  };
}

function guid() {
  function s4() {
    return Math.floor((1 + Math.random()) * 0x10000).toString(16).substring(1);
  }

  return s4() + s4() + '-' + s4() + '-' + s4() + '-' + s4() + '-' + s4() + s4() + s4();
}

function sortBy(list, props) {
  var orderList = new Array().concat(list);
  return orderList.sort(dynamicSortMultiple(props));
}

function toggleArray(array, objs) {
  if (!array) {
    return [];
  }

  var arrayClone = [].concat(array);
  objs.forEach(function (obj) {
    if (arrayClone.includes(obj)) {
      arrayClone = arrayClone.filter(function (x) {
        return x !== obj;
      });
    } else {
      arrayClone.push(obj);
    }
  });
  return arrayClone;
}

function tryParseInt(str, defaultValue) {
  var retValue = defaultValue;

  if (str !== null && str !== undefined) {
    if (str.length > 0) {
      if (!isNaN(str)) {
        retValue = parseInt(str, 10);
      }
    }
  }

  return retValue;
}

function tryParseFloat(str, defaultValue) {
  var retValue = defaultValue;

  if (str !== null && str !== undefined) {
    if (str.length >= 0) {
      if (!isNaN(str)) {
        retValue = parseFloat(str);
      }
    }
  }

  return retValue;
}

function maxChar(str, maxChar) {
  if (str && maxChar && str.length > maxChar) {
    str = str.substring(0, maxChar);
  }

  return str;
}

function slugify(str, separator, max) {
  if (!str) {
    return '';
  }

  str = str.trim();
  str = str.toLowerCase();
  var from = 'åàáãäâèéëêìíïîòóöôùúüûñç·/_,:;';
  var to = 'aaaaaaeeeeiiiioooouuuunc------';

  for (var i = 0, l = from.length; i < l; i++) {
    str = str.replace(new RegExp(from.charAt(i), 'g'), to.charAt(i));
  }

  str = str.replace(/[^a-z0-9 -]/g, '').replace(/\s+/g, '-').replace(/-+/g, '-').replace(/^-+/, '').replace(/-+$/, '').replace(/-/g, separator);
  return maxChar(str, max);
}

function compareArray(array1, array2) {
  var array1Clone = [].concat(array1).sort();
  var array2Clone = [].concat(array2).sort();
  return array1Clone.length === array2Clone.length && array1Clone.every(function (value, index) {
    return value === array2Clone[index];
  });
}

function hasSubArray(master, sub) {
  return sub.every(function (val) {
    return master.includes(val);
  });
}

function roundNumber(input, roundingType, roundingValue) {
  switch (roundingType) {
    case 'up':
      return Math.ceil(input / roundingValue) * roundingValue;

    case 'down':
      var str = (input / 60).toString();
      return parseInt(str, 10) * 60;

    case 'nearest':
      return Math.round(input / 60) * 60;

    default:
      throw new Error('roundingType not found');
  }
}

function enumToSelectList(myEnum) {
  var list = Object.keys(myEnum).filter(function (k) {
    return typeof myEnum[k] !== 'number';
  }).map(function (key) {
    return {
      id: parseInt(key, 10),
      name: "" + myEnum[key]
    };
  });
  return list.filter(function (x) {
    return x.id !== 0;
  });
}

function isMobile() {
  return document.documentElement.clientWidth <= 767;
}

function sortCaseInsensitive(arr, prop) {
  return arr.sort(function (a, b) {
    if (a[prop] && b[prop]) {
      var nameA = a[prop].toUpperCase();
      var nameB = b[prop].toUpperCase();

      if (nameA < nameB) {
        return -1;
      }

      if (nameA > nameB) {
        return 1;
      }
    }

    return 0;
  });
}

function getDefaults(dateLocales) {
  var locales = dateLocales;

  if (!locales) {
    locales = {
      today: 'Today',
      yesterday: 'Yesterday',
      thisWeek: 'This week',
      lastWeek: 'Last week',
      thisMonth: 'This week',
      lastMonth: 'Last week',
      thisQuarter: 'This quarter',
      lastQuarter: 'Last quarter',
      thisYear: 'This year',
      lastYear: 'Last year'
    };
  }

  return locales;
}

function getDateRanges(dateLocales) {
  var locales = getDefaults(dateLocales);
  return [{
    startDate: new TcDate().toDate(),
    endDate: new TcDate().toDate(),
    title: locales.today,
    view: 'day'
  }, {
    startDate: new TcDate().subtract(1, 'day').toDate(),
    endDate: new TcDate().subtract(1, 'day').toDate(),
    title: locales.yesterday,
    view: 'day'
  }, {
    startDate: new TcDate().startOf('week').toDate(),
    endDate: new TcDate().endOf('week').toDate(),
    title: locales.thisWeek,
    view: 'week'
  }, {
    startDate: new TcDate().subtract(1, 'week').startOf('week').toDate(),
    endDate: new TcDate().subtract(1, 'week').endOf('week').toDate(),
    title: locales.lastWeek,
    view: 'week'
  }, {
    startDate: new TcDate().startOf('month').toDate(),
    endDate: new TcDate().endOf('month').toDate(),
    title: locales.thisMonth,
    view: 'month'
  }, {
    startDate: new TcDate().subtract(1, 'month').startOf('month').toDate(),
    endDate: new TcDate().subtract(1, 'month').endOf('month').toDate(),
    title: locales.lastMonth,
    view: 'month'
  }, {
    startDate: new TcDate().startOf('quarter').toDate(),
    endDate: new TcDate().endOf('quarter').toDate(),
    title: locales.thisQuarter,
    view: 'quarter'
  }, {
    startDate: new TcDate().subtract(1, 'quarter').startOf('quarter').toDate(),
    endDate: new TcDate().subtract(1, 'quarter').endOf('quarter').toDate(),
    title: locales.lastQuarter,
    view: 'quarter'
  }, {
    startDate: new TcDate().startOf('year').toDate(),
    endDate: new TcDate().endOf('year').toDate(),
    title: locales.thisYear,
    view: 'year'
  }, {
    startDate: new TcDate().subtract(1, 'year').startOf('year').toDate(),
    endDate: new TcDate().subtract(1, 'year').endOf('year').toDate(),
    title: locales.lastYear,
    view: 'year'
  }];
}

function getMonthDays(date) {
  var startDate = new TcDate(date).startOf('month').toDate();
  return [].concat(Array(new TcDate(startDate).daysInMonth())).map(function (_, x) {
    return new TcDate(startDate).add(x, 'day').toDate();
  });
}

var defaults = {
  language: 'nl',
  timezone: 'Europe/Amsterdam',
  startOfWeek: 1,
  dateFormat: 'EEEE'
};
function getWeekDays(charCount, dateObject) {
  if (dateObject === void 0) {
    dateObject = defaults;
  }

  var start = new TcDate().startOf('week').date;
  var end = new TcDate().endOf('week').date;
  var ordered = new TcDate().interval(start, end).map(function (x) {
    return new LocaleDate(new TcDate(x).toDate(), dateObject).toDate();
  });

  if (charCount) {
    return ordered.map(function (x) {
      return x.substring(0, charCount).toUpperCase();
    });
  } else {
    return ordered;
  }
}

function getInputValueByName(name) {
  var field = document.getElementsByName(name);

  if (field && field.length > 0) {
    return field[0].value;
  }

  return null;
}
function setInputValueByName(name, value) {
  var field = document.getElementsByName(name);

  if (field && field.length > 0) {
    var input = field[0];
    input.value = value;
  }
}
function setInputCheckedByName(name, checked) {
  var field = document.getElementsByName(name);

  if (field && field.length > 0) {
    var input = field[0];
    input.checked = checked;
  }
}

exports.LocaleDate = LocaleDate;
exports.TcDate = TcDate;
exports.cloneObject = cloneObject;
exports.compareArray = compareArray;
exports.dynamicSort = dynamicSort;
exports.dynamicSortMultiple = dynamicSortMultiple;
exports.enumToSelectList = enumToSelectList;
exports.formatCurrency = formatCurrency;
exports.formatDate = formatDate;
exports.formatDateInput = formatDateInput;
exports.formatDistance = formatDistance;
exports.formatFloat = formatFloat;
exports.formatNumber = formatNumber;
exports.formatTime = formatTime;
exports.formatUppercase = formatUppercase;
exports.getDateRanges = getDateRanges;
exports.getInputValueByName = getInputValueByName;
exports.getMonthDays = getMonthDays;
exports.getWeekDays = getWeekDays;
exports.globalVarExists = globalVarExists;
exports.guid = guid;
exports.hasSubArray = hasSubArray;
exports.isMobile = isMobile;
exports.maxChar = maxChar;
exports.roundNumber = roundNumber;
exports.setInputCheckedByName = setInputCheckedByName;
exports.setInputValueByName = setInputValueByName;
exports.slugify = slugify;
exports.sortBy = sortBy;
exports.sortCaseInsensitive = sortCaseInsensitive;
exports.toggleArray = toggleArray;
exports.tryParseFloat = tryParseFloat;
exports.tryParseInt = tryParseInt;
exports.unformatCurrency = unformatCurrency;
//# sourceMappingURL=timechimp-typescript-helpers.cjs.development.js.map
